# coding:utf-8
from optparse import make_option
from django.core.management.base import BaseCommand, CommandError

from concentrator.dict.proxy import (
    GroupAgeSubCathegoryProxy, LoadData, HealthNeedProxy, PrivilegeProxy,
    UnitProxy, GroupStatisticProxy)
from concentrator.dict.constants import (OperationEnumerate,
                                                        ModelForSend)


class Command(BaseCommand):

    help = 'Send dictionaries info to concentrator [-U] [--size]'
    option_list = BaseCommand.option_list + (
        make_option(
            '-O',
            action='store',
            dest='mode',
            choices=[OperationEnumerate.UPDATE,
                     OperationEnumerate.ADD,
                     OperationEnumerate.DELETE],
            default=OperationEnumerate.UPDATE,
            help='Send data to update, delete or adding it'
        ),
        make_option(
            '-D',
            action='store',
            dest='dict',
            choices=ModelForSend.values.keys(),
            default=ModelForSend.UNIT,
            help='NameDict'
        ),
        make_option(
            '--size',
            action='store',
            dest='size',
            default=200,
            help='Send data to update instead of adding it'
        ),
    )

    def handle(self, *args, **options):
        """
        Если команда вызвана с ключом -U, то данные
        будут отправлены на обновление. В противном случае - на добавление.
        """
        operation = options['mode']
        try:
            size = int(options['size'])
        except ValueError:
            raise CommandError(
                u'option --size must have an integer argument. '
                u'Example: --size 10')

        proxy_classes = (
            GroupAgeSubCathegoryProxy,
            HealthNeedProxy,
            PrivilegeProxy,
            UnitProxy,
            GroupStatisticProxy,
        )
        for proxy_class in proxy_classes:
            if options['dict'] == proxy_class.__name__:
                proxy_class().send_all(operation, size)




